#include <unistd.h>
#include <stdio.h>
#include <math.h>

int initialize(int N, double *T[], double *dT[]) {

//------------------------------------------------------------------------------
// Set the interior nodes of a rectangular (N+2) x (N+2) mesh to all zeros.
// Although this returns an error flag, about the only possible error is if the
// loop bounds cause debroument. In that case, I'll let GCC do the barfage.
// [To any CS software weenies: yes, I know how to do try/catch, etc. But it's
// not worth the effort for this code.]
//
// The arrays are allocated in main() by calloc(), which means they are set to
// all zeros automatically. But if you call multiple versions of the solver in a
// single run, it is necessary to reset T and dT - which is why this honker is here.
//----------------
// Randall Bramley
// Department of Computer Science
// Indiana University, Bloomington
//----------------
// Last Modified: Wed 24 Jan 2018, 12:56 PM
//------------------------------------------------------------------------------

    int i, j;

    // I use a separate loop nest for dT since it has different bounds. This
    // is outside the timing loop anyway, so it's not worth trying to merge
    // the two loop nests.
    for (i = 1; i < N+1; ++i) 
        for (j = 1; j < N+1; ++j) 
            T[i][j] = 0.0;

    // It is important to have the dT boundary nodes set to zero; the interior
    // nodes are gonna be changed before it is added to T, so those are
    // less important.
    for (i = 0; i < N+2; ++i) 
        for (j = 0; j < N+2; ++j)
            dT[i][j] = 0.0;
        
    return 0;
}
