#-----------------------------------------------------------------------------
# By (un)commenting lines below, can choose between Intel + MKL or GNU + gsl
# Be sure to not mix up those up; changing the compiler requires changing the
# libs and most of the optimizations.
#
# Auto variables:
# 	$@ = filename representing target
# 	$% = filename element of an archive 
# 	$< = filename of first prereq
# 	$? = names of all prereqs (space separated) newer than the target
# 	$^ - filenames of all prereqs, no dups
# 	$* = stem of target filename
#
# Append D to get directory part of the value, e.g., $(*D)
#
# For fortran module files:
# 	1. Make the executable dependon the .o file
# 	2. Make the sources that use the module depend on the .mod file
# 	3. On the target line for the module, make both .o and .mod depend on 
# 	the .f90 file., viz.,
# 	kindlytypes.o kindlytypes.mod: kindlytypes.f90
# 		$(F95) -c kindlytypes.f90
#
# For the gfortran -finit-real=nan option beware that
# 1. it does not initialize allocatable arrays or components of derived types
# 2. As the man pages warn:
#   "note that enabling any of the -finit-* options will silence warnings 
# 	that would have been emitted by -Wuninitialized for the affected local 
# 	variables."
#
#------------------------------------
# Last Modified: Wed 24 Jan 2018, 12:48 PM
#-----------------------------------------------------------------------------

MAKEFLAGS += r
# Prevents attempts to regard .mod files as modula-2 and using m2c to compile
# them into .c files:
%.o : %.mod 

#===== Compilers =================================================================
CC=gcc

# F90=ifort
F90=gfortran
F95=$(F90)

#===== Optimizations =============================================================

# ifeq (F95,"gfortran")       # does not work, even with $(F90) and no ws in F90 
ifeq "$(strip $(F95))" "gfortran"
	OPTS = \
	-O3 \
	-fdiagnostics-color=auto  \
	-ftree-vectorize \
	-fopenmp \
	-funroll-loops \
	--param max-unroll-times=4 \
	-ffast-math \
	-ffp-contract=fast \
	-march=native 

	# few codes can run with these settings:
	# -ffpe-trap=zero,overflow,underflow,invalid,inexact 

else
	OPTS = -O3     \
    -opt-prefetch   \
    -align all      \
    -ccdefault none \
    -ftz            \
    -funroll-loops  \
    -falign-functions=16 \
    -fp-model fast=2 \
    -fp-speculation=fast \
    -opt-prefetch \
    -no-prec-div \
    -xHost \
	-assume realloc_lhs \
	-assume protect_parens \
	-openmp 	

endif

# Make sure that any build knows which targets are not files
.PHONY: install clean kleen

# use -xAVX in behemoth, or other systems where the cpu supports
# it. I.e., AVX > SSE4.2. When compiling on the machine to execute
# the code, -xHost should take care of that.


#===== Libraries and Other Effluvia ==============================================
LIBS = -lm 

# Use the 2013 Intel libs:
# MKLROOT = /opt/intel/composer_xe_2013.3.163/mkl
# LIBS =   -L$(MKLROOT)/lib/intel64 -lmkl_rt -lpthread -lm
# add -lgomp for OpenMP with the Intel compiler
#---------------------------------------
# For GNU gfortran and GSL: 
# LIBS = -L/usr/lib/ -lgsl -lblas
# 
