
% Compare the different methods for numbers of iterations, elapsed time,
% computational rate. This assumes the format for the file "results" has
% on each row
% N  threads  iter  errornorm   time   gflops     method
%
% It also outputs the match between method numbers and names at the end.
%
% Beware: this only makes sense for runs where only the method number
% changes. N, tolerance, and maxits need to remain the same for all of
% the data loaded from the file "results".
%

G = load('results');
iter   = G(:,3);
time   = G(:,5);
gflops = G(:,6);
method = G(:,7);

% If more than one run per method is done, this prevents having lines
% going back and forth among the method numbers.
[method, I] = sort(method);
iter = iter(I);
time = time(I);
gflops = gflops(I);

figure
subplot(1,3,1)
plot(method, iter, 'b+-')
xlabel('Method #')
ylabel('Iters')
title('Iterations')

subplot(1,3,2)
plot(method, time, 'g*-')
xlabel('Method #')
ylabel('Time (s)')
title('Elapsed Time')

subplot(1,3,3)
plot(method, gflops, 'cd-')
xlabel('Method #')
ylabel('Gflops')
title('Gflops/sec')

% Remaining stuff is to print to the screen a legend to allow mapping 
% method number to just WTH the method is.
methods{1} = 'Jacobi';
methods{2} = 'Gauss-Seidel';
methods{3} = 'OMP Jacobi';
methods{4} = 'OMP Gauss-Seidel';

for k = 1:length(methods)
    disp([num2str(k) ': ' methods{k}])
end

